@@ -1,4 +1,5 @@
 from webspace.cms import constants
+from webspace.cms.blocks.choice import ThemeChoiceBlock
 from webspace.cms.blocks.common import \
     FormBlock, \
     EntryBlock
@@ -6,10 +7,9 @@ from webspace.cms.blocks.common import \
 
 class FormEntry(EntryBlock):
     amp_scripts = ['form']
+    theme_reverse = ThemeChoiceBlock(required=False)
     form = FormBlock()
 
-    pass
-
     def mock(self, *args, **kwargs):
         form = self.get_form('big')
         self.mock_data.update({
