@@ -4,7 +4,7 @@ from wagtail.core.models import Page
 
 
 class Command(BaseCommand):
-    help = 'Cache commands : update'
+    help = 'Page commands : update'
 
     def add_arguments(self, parser):
         parser.add_argument('action', type=str)
